@@ -20,9 +20,10 @@ sub register {
     # Add conditions
     $app->routes->add_condition(authenticated => \&authenticated);
 
-    # Load routes if they are passed
+    #Add to classes used for finding templates in DATA sections
     push @{$app->renderer->classes}, __PACKAGE__;
 
+    # Load routes if they are passed
     $app->load_routes($config->{routes}) if (@{$config->{routes}});
     return $self;
 }
@@ -158,7 +159,8 @@ Ado::Plugin::Auth - Authenticate users
   plugins =>[
     #...
     {name => 'auth', config => {
-        services =>['ado', 'facebook',...]
+        auth_methods =>['ado', 'facebook',...],
+        routes => [...]
       }
     }
     #...
@@ -186,7 +188,7 @@ in any other template on your site.
   plugins =>[
     #...
     {name => 'auth', config => {
-        services =>['ado', 'facebook',...]
+        auth_methods =>['ado', 'facebook',...]
       }
     }
     #...
@@ -199,6 +201,11 @@ To find more about conditions read L<Mojolicious::Guides::Routing/Conditions>.
 
 =head2 authenticated
 
+Condition for routes used to check if a user is authenticated.
+Additional parameters can be passed to specify the preferred 
+authentication method to be preselected in the login form
+if condition redirects to C</login/:auth_method>.
+
   # add the condition programatically
   $app->routes->route('/ado-users/:action', over => {authenticated=>1});
   $app->routes->route('/ado-users/:action', 
@@ -214,20 +221,16 @@ To find more about conditions read L<Mojolicious::Guides::Routing/Conditions>.
       
       # only authenticated users can edit and delete users,
       # and only if they are authorized to do so
-      over =>over => [authenticated => 1, authz => {group => 'admin'}],
+      over => [authenticated => 1, authz => {group => 'admin'}],
       to =>'ado-users#edit'
     }
   ],
 
-Condition for routes used to check if a user is authenticated.
-Additional parameters can be passed to specify the preferred authentication method to be
-preselected in the login form
-if condition redirects to C</login/:auth_method>.
 
 
 =head1 HELPERS
 
-L<Ado::Plugin::Auth> exports the following helpers for use in  
+L<Ado::Plugin::Auth> provides the following helpers for use in  
 L<Ado::Control> methods and templates.
 
 
@@ -236,19 +239,37 @@ L<Ado::Control> methods and templates.
 
 L<Ado::Plugin::Auth> provides the following routes (actions):
 
-=head2 login
+=head2 /login
 
   /login/:auth_method
 
 If accessed using a C<GET> request displays a login form.
 If accessed via C<POST> performs authentication using C<:auth_method>.
 
-=head2 logout
+=head2 /logout
 
 Expires the session and redirects to the base URL.
 
   $c->logout();
 
+=head1 TEMPLATES
+
+L<Ado::Plugin::Auth> embeds the following templates. You can run C<ado inflate> and modify them.
+Usage examples can be found at L<http://localhost:3000> after starting ado.
+
+=head2 partials/authbar.html.ep
+
+Renders a menu dropdown for choosing methods for signing in.
+
+=head2 partials/login_form.html.ep
+
+Renders a Login form.
+
+
+=head2 login.html.ep
+
+Renders a page containing the login form.
+
 =head1 METHODS
 
 L<Ado::Plugin::Auth> inherits all methods from
@@ -303,7 +324,7 @@ __DATA__
 %# displayed as a menu item
 <div class="right compact menu" id="authbar">
 % if (user->login_name eq 'guest') {
-  <div class="ui simple dropdown item" title="Sign in with">
+  <div class="ui simple dropdown item" title="<%=l('Sign in with') %>">
     <i class="sign in icon"></i>
     <div class="menu">
     % for my $auth(@{app->config('auth_methods')}){
